==> react-molecule-coachmark-0.5.0.tgz: package/lib/Tooltip/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import PropTypes from 'prop-types';
import AtomButton, { atomButtonColors, atomButtonDesigns, atomButtonShapes, atomButtonSizes } from '@s-ui/react-atom-button';
import AtomImage from '@s-ui/react-atom-image';
import { BASE_CLASS, DEFAULT_TOOLTIP_ACTION_BUTTONS_IDS, MINIMUM_COACHMARK_STEPS } from '../settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Tooltip = function Tooltip(_ref) {
  var _ref$tooltipOptions = _ref.tooltipOptions,
    tooltipOptions = _ref$tooltipOptions === void 0 ? {} : _ref$tooltipOptions,
    index = _ref.index,
    isLastStep = _ref.isLastStep,
    primaryProps = _ref.primaryProps,
    totalSteps = _ref.size,
    skipProps = _ref.skipProps,
    step = _ref.step,
    tooltipProps = _ref.tooltipProps,
    backProps = _ref.backProps,
    hideBackButton = _ref.hideBackButton,
    showProgress = _ref.showProgress;
  return /*#__PURE__*/_jsxs("div", _extends({
    className: BASE_CLASS + "-tooltip"
  }, tooltipProps, {
    children: [/*#__PURE__*/_jsxs("header", {
      className: BASE_CLASS + "-tooltipHeader",
      children: [tooltipOptions.badge ? /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-tooltipBadge",
        children: tooltipOptions.badge
      }) : null, tooltipOptions.closeIcon ? /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-tooltipCloseButton",
        children: /*#__PURE__*/_jsx(AtomButton, _extends({
          color: atomButtonColors.NEUTRAL,
          design: atomButtonDesigns.FLAT,
          size: atomButtonSizes.SMALL,
          shape: atomButtonShapes.CIRCULAR,
          leftIcon: tooltipOptions.closeIcon
        }, skipProps))
      }) : null]
    }), /*#__PURE__*/_jsxs("div", {
      className: BASE_CLASS + "-tooltipContent",
      children: [tooltipOptions.image ? /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-tooltipImageContainer",
        children: /*#__PURE__*/_jsx("div", {
          className: BASE_CLASS + "-tooltipImage",
          children: /*#__PURE__*/_jsx(AtomImage, {
            src: tooltipOptions.image.url,
            alt: tooltipOptions.image.alt
          })
        })
      }) : null, /*#__PURE__*/_jsxs("div", {
        className: BASE_CLASS + "-tooltipTexts",
        children: [step.title && /*#__PURE__*/_jsx("h1", {
          className: BASE_CLASS + "-tooltipHeadingText",
          children: step.title
        }), /*#__PURE__*/_jsx("p", {
          className: BASE_CLASS + "-tooltipBodyText",
          children: step.content
        })]
      })]
    }), /*#__PURE__*/_jsxs("div", {
      className: BASE_CLASS + "-tooltipFooter",
      children: [showProgress && totalSteps > MINIMUM_COACHMARK_STEPS && /*#__PURE__*/_jsx("p", {
        className: BASE_CLASS + "-tooltipStepCounter",
        children: index + 1 + "/" + totalSteps
      }), /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-tooltipButtons",
        children: tooltipOptions != null && tooltipOptions.actionButtons ? tooltipOptions.actionButtons.map(function (_ref2) {
          var id = _ref2.id,
            color = _ref2.color,
            size = _ref2.size,
            design = _ref2.design,
            shape = _ref2.shape,
            isNegative = _ref2.isNegative;
          var isBackButton = DEFAULT_TOOLTIP_ACTION_BUTTONS_IDS.BACK === id;
          var isNextButton = DEFAULT_TOOLTIP_ACTION_BUTTONS_IDS.NEXT === id;
          var isBackButtonHidden = isBackButton && index === 0 || isBackButton && hideBackButton;
          var getButtonText = function getButtonText() {
            if (isNextButton) {
              return isLastStep ? step.locale.last : step.locale.next;
            }
            return step.locale.back;
          };
          var buttonProps = isBackButton && !isBackButtonHidden ? backProps : primaryProps;
          return isBackButtonHidden ? null : /*#__PURE__*/_jsx(AtomButton, _extends({
            color: color,
            design: design,
            size: size,
            shape: shape,
            negative: isNegative
          }, buttonProps, {
            children: getButtonText()
          }));
        }) : null
      })]
    })]
  }));
};
export default Tooltip;

==> react-molecule-coachmark-0.6.0.tgz: package/lib/Tooltip/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import PropTypes from 'prop-types';
import AtomButton, { atomButtonColors, atomButtonDesigns, atomButtonShapes, atomButtonSizes } from '@s-ui/react-atom-button';
import AtomImage from '@s-ui/react-atom-image';
import { BASE_CLASS, DEFAULT_TOOLTIP_ACTION_BUTTONS_IDS, MINIMUM_COACHMARK_STEPS } from '../settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Tooltip = function Tooltip(_ref) {
  var _ref$tooltipOptions = _ref.tooltipOptions,
    tooltipOptions = _ref$tooltipOptions === void 0 ? {} : _ref$tooltipOptions,
    index = _ref.index,
    isLastStep = _ref.isLastStep,
    primaryProps = _ref.primaryProps,
    totalSteps = _ref.size,
    skipProps = _ref.skipProps,
    step = _ref.step,
    tooltipProps = _ref.tooltipProps,
    backProps = _ref.backProps,
    hideBackButton = _ref.hideBackButton,
    showProgress = _ref.showProgress;
  return /*#__PURE__*/_jsxs("div", _extends({
    className: BASE_CLASS + "-tooltip"
  }, tooltipProps, {
    children: [/*#__PURE__*/_jsxs("header", {
      className: BASE_CLASS + "-tooltipHeader",
      children: [tooltipOptions.badge ? /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-tooltipBadge",
        children: tooltipOptions.badge
      }) : null, tooltipOptions.closeIcon ? /*#__PURE__*/_jsx("div", _extends({
        className: BASE_CLASS + "-tooltipCloseButton"
      }, skipProps, {
        children: tooltipOptions.closeIcon
      })) : null]
    }), /*#__PURE__*/_jsxs("div", {
      className: BASE_CLASS + "-tooltipContent",
      children: [tooltipOptions.image ? /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-tooltipImageContainer",
        children: /*#__PURE__*/_jsx("div", {
          className: BASE_CLASS + "-tooltipImage",
          children: /*#__PURE__*/_jsx(AtomImage, {
            src: tooltipOptions.image.url,
            alt: tooltipOptions.image.alt
          })
        })
      }) : null, /*#__PURE__*/_jsxs("div", {
        className: BASE_CLASS + "-tooltipTexts",
        children: [step.title && /*#__PURE__*/_jsx("h1", {
          className: BASE_CLASS + "-tooltipHeadingText",
          children: step.title
        }), /*#__PURE__*/_jsx("p", {
          className: BASE_CLASS + "-tooltipBodyText",
          children: step.content
        })]
      })]
    }), /*#__PURE__*/_jsxs("div", {
      className: BASE_CLASS + "-tooltipFooter",
      children: [showProgress && totalSteps > MINIMUM_COACHMARK_STEPS && /*#__PURE__*/_jsx("p", {
        className: BASE_CLASS + "-tooltipStepCounter",
        children: index + 1 + "/" + totalSteps
      }), /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-tooltipButtons",
        children: tooltipOptions != null && tooltipOptions.actionButtons ? tooltipOptions.actionButtons.map(function (_ref2) {
          var id = _ref2.id,
            color = _ref2.color,
            size = _ref2.size,
            design = _ref2.design,
            shape = _ref2.shape,
            isNegative = _ref2.isNegative;
          var isBackButton = DEFAULT_TOOLTIP_ACTION_BUTTONS_IDS.BACK === id;
          var isNextButton = DEFAULT_TOOLTIP_ACTION_BUTTONS_IDS.NEXT === id;
          var isBackButtonHidden = isBackButton && index === 0 || isBackButton && hideBackButton;
          var getButtonText = function getButtonText() {
            if (isNextButton) {
              return isLastStep ? step.locale.last : step.locale.next;
            }
            return step.locale.back;
          };
          var buttonProps = isBackButton && !isBackButtonHidden ? backProps : primaryProps;
          return isBackButtonHidden ? null : /*#__PURE__*/_jsx(AtomButton, _extends({
            color: color,
            design: design,
            size: size,
            shape: shape,
            negative: isNegative
          }, buttonProps, {
            children: getButtonText()
          }));
        }) : null
      })]
    })]
  }));
};
export default Tooltip;
